OC.L10N.register(
    "contacts",
    {
    "Details" : "معلومات",
    "Invalid image" : "انځور سم نه دی",
    "Name" : "نوم",
    "Download" : "ښکته کول",
    "Delete" : "ړنګول",
    "Cancel" : "پرېښول",
    "Groups" : "ګروپونه",
    "Rename" : "نوم بدلول",
    "Copy link" : "لېنک کاپي کول",
    "Notes" : "شسیب",
    "Home" : "کور",
    "Work" : "دفتر",
    "Other" : "نور"
},
"nplurals=2; plural=(n != 1);");
